import * as z from "zod";
import { ValidatorError } from "./validator.error.mjs";

/**
 * @template T
 * @param {z.ZodObject<T>} schema
 * @returns {(maybeValid: unknown) => T}
 */
export const validator = (schema) => (maybeValid) => {
  const result = schema.safeParse(maybeValid);
  if (!result.success) {
    throw new ValidatorError(result.error.errors);
  }
  return result.data;
};
