/**
 * Custom router class
 *
 * @export
 * @class Router
 * @abstract
 */
export class Router {
    /**
     * Creates an instance of Router.
     * @constructor
     * @param {string} path
     */
    constructor(path: string);
    /**
     * @public
     * @readonly
     * @type {express.Router}
     */
    public readonly get router(): express.Router;
    /**
     * @public
     * @readonly
     * @type {string}
     */
    public readonly get path(): string;
    /**
     * @public
     * @param {Router} router
     * @returns {this}
     */
    public subRoute(router: Router): this;
    /**
     * @public
     * @param {string} path
     * @param {RequestHandler} handler
     * @param {...RequestHandler} middlewares
     * @returns {this}
     */
    public get(path: string, handler: RequestHandler, ...middlewares: RequestHandler[]): this;
    /**
     * @public
     * @param {string} path
     * @param {RequestHandler} handler
     * @param {...RequestHandler} middlewares
     * @returns {this}
     */
    public post(path: string, handler: RequestHandler, ...middlewares: RequestHandler[]): this;
    /**
     * @public
     * @param {string} path
     * @param {RequestHandler} handler
     * @param {...RequestHandler} middlewares
     * @returns {this}
     */
    public put(path: string, handler: RequestHandler, ...middlewares: RequestHandler[]): this;
    /**
     * @public
     * @param {string} path
     * @param {RequestHandler} handler
     * @param {...RequestHandler} middlewares
     * @returns {this}
     */
    public delete(path: string, handler: RequestHandler, ...middlewares: RequestHandler[]): this;
    /**
     * @public
     * @param {string} path
     * @param {RequestHandler} handler
     * @param {...RequestHandler} middlewares
     * @returns {this}
     */
    public patch(path: string, handler: RequestHandler, ...middlewares: RequestHandler[]): this;
    /**
     * @public
     * @param {string} path
     * @param {RequestHandler} handler
     * @param {...RequestHandler} middlewares
     * @returns {this}
     */
    public options(path: string, handler: RequestHandler, ...middlewares: RequestHandler[]): this;
    /**
     * @public
     * @param {string} path
     * @param {RequestHandler} handler
     * @param {...RequestHandler} middlewares
     * @returns {this}
     */
    public head(path: string, handler: RequestHandler, ...middlewares: RequestHandler[]): this;
    #private;
}
export type RequestHandler = (req: express.Request, res: import('../middlewares/custom-response.middleware.mjs').Response, next?: express.NextFunction) => void;
import express from "express";
